@@ -13,7 +13,7 @@ def create_one_off_charge(
     charge_name: str
 ) -> dict:
     """
-    https://developer.paddle.com/api-reference/subscription-api/one-off-charges/createcharge
+    `Create One-off Charge Paddle docs <https://developer.paddle.com/api-reference/subscription-api/one-off-charges/createcharge>`_
 
     This endpoint currently only supports x-www-form-urlencoded not json
     unlike most of the other Paddle endpoints
@@ -23,10 +23,12 @@ def create_one_off_charge(
     Please put a proper product / charge name here to make it clear what buyers
     are buying. Here are some examples:
 
-    [add-on name] x [quantity] e.g. Supercool design plugin x 1
-    [number of credits] credits for [subscription plan] e.g. 200 credits for Monthly talk time    # NOQA: E501
-    [quantity] [units] [product description] e.g. 124 MB data usage
-    """
+    - [add-on name] x [quantity] e.g. Supercool design plugin x 1
+
+    - [number of credits] credits for [subscription plan] e.g. 200 credits for Monthly talk time
+
+    - [quantity] [units] [product description] e.g. 124 MB data usage
+    """  # NOQA: E501
     url = 'subscription/{0}/charge'.format(subscription_id)
     url = urljoin(self.vendors_v2, url)
 
